@@ -17,6 +17,7 @@ from typing import Any
 from typing import Dict
 from typing import IO
 from typing import Optional
+from typing import Union
 
 from .build_constants import BUILD_GCLOUD_REST
 
@@ -35,7 +36,7 @@ log = logging.getLogger(__name__)
 class BaseSession(object):
     __metaclass__ = ABCMeta
 
-    def __init__(self, session                    = None, timeout      = 10,
+    def __init__(self, session                    = None, timeout        = 10,
                  verify_ssl       = True)        :
         self._shared_session = bool(session)
         self._session = session
@@ -48,30 +49,30 @@ class BaseSession(object):
 
     @abstractmethod
     def post(self, url     , headers                ,
-                   data               , timeout     ,
+                   data               , timeout       ,
                    params                          )            :
         pass
 
     @abstractmethod
     def get(self, url     , headers                          ,
-                  timeout     , params                          ,
+                  timeout       , params                          ,
                   stream      )            :
         pass
 
     @abstractmethod
     def patch(self, url     , headers                ,
-                    data               , timeout     ,
+                    data               , timeout       ,
                     params                          )            :
         pass
 
     @abstractmethod
     def put(self, url     , headers                , data         ,
-                  timeout     )            :
+                  timeout       )            :
         pass
 
     @abstractmethod
     def delete(self, url     , headers                ,
-                     params                , timeout     )            :
+                     params                , timeout       )            :
         pass
 
     @abstractmethod
@@ -88,6 +89,8 @@ class BaseSession(object):
 if not BUILD_GCLOUD_REST:
     import aiohttp
 
+    Timeout = Union[aiohttp.ClientTimeout, float]
+
     def _raise_for_status(resp                        )        :
         """Check resp for status and if error log additional info."""
         # Copied from aiohttp's raise_for_status() -- since it releases the
@@ -117,64 +120,67 @@ if not BUILD_GCLOUD_REST:
                                               headers=resp.headers)
 
     class AioSession(BaseSession):
+        #_session: aiohttp.ClientSession
+        #_timeout: Timeout
+
         @property
         def session(self)                         :
             if not self._session:
                 connector = aiohttp.TCPConnector(ssl=self._ssl)
-                timeout = aiohttp.ClientTimeout(self._timeout)
+
+                if isinstance(self._timeout, aiohttp.ClientTimeout):
+                    timeout = self._timeout
+                else:
+                    timeout = aiohttp.ClientTimeout(total=self._timeout)
+
                 self._session = aiohttp.ClientSession(connector=connector,
                                                       timeout=timeout)
             return self._session
 
         def post(self, url     , headers                ,
-                       data                = None, timeout      = 10,
+                       data                = None, timeout          = 10,
                        params                           = None
                        )                          :
-            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.post(url, data=data, headers=headers,
-                                           timeout=timeout_, params=params)
+                                           timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
         def get(self, url     , headers                           = None,
-                      timeout      = 10,
+                      timeout          = 10,
                       params                           = None,
                       stream                 = None)                          :
             if stream is not None:
                 log.warning('passed unused argument stream=%s to AioSession: '
                             'this argument is only used by SyncSession',
                             stream)
-            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.get(url, headers=headers,
-                                          timeout=timeout_, params=params)
+                                          timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
         def patch(self, url     , headers                ,
-                        data                = None, timeout      = 10,
+                        data                = None, timeout          = 10,
                         params                           = None
                         )                          :
-            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.patch(url, data=data, headers=headers,
-                                            timeout=timeout_, params=params)
+                                            timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
         def put(self, url     , headers                , data         ,
-                      timeout      = 10)                          :
-            timeout_ = aiohttp.ClientTimeout(timeout)
+                      timeout          = 10)                          :
             resp = self.session.put(url, data=data, headers=headers,
-                                          timeout=timeout_)
+                                          timeout=timeout)
             _raise_for_status(resp)
             return resp
 
         def delete(self, url     , headers                ,
                          params                           = None,
-                         timeout      = 10
+                         timeout          = 10
                          )                          :
-            timeout_ = aiohttp.ClientTimeout(timeout)
             resp = self.session.delete(url, headers=headers,
-                                             params=params, timeout=timeout_)
+                                             params=params, timeout=timeout)
             _raise_for_status(resp)
             return resp
 
@@ -189,7 +195,7 @@ if not BUILD_GCLOUD_REST:
 
         def close(self)        :
             if not self._shared_session and self._session:
-                self._session.close()  # type: ignore[func-returns-value]
+                self._session.close()
 
 
 if BUILD_GCLOUD_REST:
@@ -211,7 +217,7 @@ if BUILD_GCLOUD_REST:
         # symbol ensures we match the base class's definition for static
         # analysis.
         def post(self, url     , headers                ,
-                       data                = None, timeout      = 10,
+                       data                = None, timeout        = 10,
                        params                           = None)            :
             with self.google_api_lock:
                 resp = self.session.post(url, data=data, headers=headers,
@@ -220,7 +226,7 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def get(self, url     , headers                           = None,
-                      timeout      = 10,
+                      timeout        = 10,
                       params                           = None,
                       stream       = False)            :
             with self.google_api_lock:
@@ -230,7 +236,7 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def patch(self, url     , headers                ,
-                        data                = None, timeout      = 10,
+                        data                = None, timeout        = 10,
                         params                           = None)            :
             with self.google_api_lock:
                 resp = self.session.patch(url, data=data, headers=headers,
@@ -239,7 +245,7 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def put(self, url     , headers                , data         ,
-                      timeout      = 10)            :
+                      timeout        = 10)            :
             with self.google_api_lock:
                 resp = self.session.put(url, data=data, headers=headers,
                                         timeout=timeout)
@@ -248,7 +254,7 @@ if BUILD_GCLOUD_REST:
 
         def delete(self, url     , headers                ,
                          params                           = None,
-                         timeout      = 10
+                         timeout        = 10
                          )            :
             with self.google_api_lock:
                 resp = self.session.delete(url, params=params, headers=headers,
